@@ -24,8 +24,8 @@ See the readme at https://github.com/pyronicide/janky.post for more details.
 __author__ = 'Thomas Rampelberg'
 __author_email__ = 'thomas@saunter.org'
 
+from django.utils import simplejson as json
 from google.appengine.ext import webapp
-import json
 import logging
 import urlparse
 
@@ -54,7 +54,7 @@ class JankyMiddleware(object):
                         'resp': json.dumps(body), 
                         'origin': json.dumps(urlparse.urljoin(
                                 webapp.Request(environ).get('_origin'), 
-                                '/janky.html'))
+                                '/janky'))
                         }
                 write(body)
             return my_write
